@@ -57,7 +57,7 @@
 #define ICON_BRIEFCASE     ICON_STR(FA_BRIEFCASE, "󰃖", "💼")
 #define ICON_C             ICON_STR(MFIZZ_C, "", "🇨 ")
 #define ICON_CHANGELOG     ICON_STR(FA_HISTORY, "󰋚", "🔺")
-#define ICON_CHESS         ICON_STR("", "󰄺", "")
+#define ICON_CHESS         ICON_STR("", "󰄺", "♟️ ")
 #define ICON_CLOJURE       ICON_STR(MFIZZ_CLOJURE, "", "")
 #define ICON_CONFIGURE     ICON_STR(FILE_CONFIG, "", "🔧")
 #define ICON_CPLUSPLUS     ICON_STR(MFIZZ_CPLUSPLUS, "", ICON_C)
@@ -69,63 +69,63 @@
 #define ICON_ELIXIR        ICON_STR(MFIZZ_ELIXIR, "", "💧")
 #define ICON_ENCRYPT       ICON_STR("", "󰌆", "🔒")
 #define ICON_FSHARP        ICON_STR(DEV_FSHARP, "", "")
-#define ICON_FONT          ICON_STR(FILE_FONT, "", "")
+#define ICON_FONT          ICON_STR(FILE_FONT, "", "🔤")
 #define ICON_GIT           ICON_STR(FA_GIT, "", "🌱")
 #define ICON_HASKELL       ICON_STR("", "", "")
-#define ICON_HTML          ICON_STR(FA_FILE_CODE_O, "󰌝", "")
+#define ICON_HTML          ICON_STR(FA_FILE_CODE_O, "󰌝", "🌍")
 #define ICON_JAVA          ICON_STR(MFIZZ_JAVA, "", "☕")
-#define ICON_JAVASCRIPT    ICON_STR(FA_FILE_CODE_O, "󰌞", "")
+#define ICON_JAVASCRIPT    ICON_STR(FA_FILE_CODE_O, "󰌞", ICON_SCRIPT)
 #define ICON_LICENSE       ICON_STR(FA_COPYRIGHT, "󰈙", "⚖️ ")
 #define ICON_LINUX         ICON_STR(FA_LINUX, "󰌽", "🐧")
 #define ICON_MAKEFILE      ICON_STR(FILE_CMAKE, "󰆍", "🛠 ")
 #define ICON_MANUAL        ICON_STR(FILE_MANPAGE, "󱓷", "❓")
-#define ICON_MS_EXCEL      ICON_STR(FILE_EXCEL, "󰈛", ICON_WORDDOC)
+#define ICON_MS_EXCEL      ICON_STR(FILE_EXCEL, "󰈛", "📗")
 #define ICON_MUSIC         ICON_STR(FA_MUSIC, "󱍙", "🎧")
-#define ICON_MUSICFILE     ICON_STR(FA_FILE_AUDIO_O, "󰎈", ICON_MUSIC)
+#define ICON_MUSICFILE     ICON_STR(FA_FILE_AUDIO_O, "󰎈", "🎵")
 #define ICON_OPTICALDISK   ICON_STR(LINEA_MUSIC_CD, "", "💿")
 #define ICON_PDF           ICON_STR(FA_FILE_PDF_O, "󰈦", "📕")
-#define ICON_PHOTOSHOP     ICON_STR(DEV_PHOTOSHOP, "", ICON_PICTUREFILE)
-#define ICON_PICTUREFILE   ICON_STR(FA_FILE_IMAGE_O, "󰈟", ICON_PICTURES)
+#define ICON_PHOTOSHOP     ICON_STR(DEV_PHOTOSHOP, "", "🖌️ ")
+#define ICON_PICTUREFILE   ICON_STR(FA_FILE_IMAGE_O, "󰈟", "🖼️ ")
 #define ICON_PICTURES      ICON_STR(MD_CAMERA_ALT, "󰉔", "🎨")
-#define ICON_PLAYLIST      ICON_STR(ICON_MUSICFILE, "󱍙", "")
+#define ICON_PLAYLIST      ICON_STR(ICON_MUSICFILE, "󱍙", "🎶")
 #define ICON_POWERPOINT    ICON_STR(FILE_POWERPOINT, "󰈧", "📊")
 #define ICON_PUBLIC        ICON_STR(FA_INBOX, "", "👀")
 #define ICON_PYTHON        ICON_STR(MFIZZ_PYTHON, "", "🐍")
 #define ICON_REACT         ICON_STR(FILE_JSX, "", ICON_JAVASCRIPT)
 #define ICON_RUBY          ICON_STR(MFIZZ_RUBY, "", "💎")
-#define ICON_RUST          ICON_STR(DEV_RUST, "", "")
-#define ICON_SASS          ICON_STR("", "", "")
+#define ICON_RUST          ICON_STR(DEV_RUST, "", "🦀")
+#define ICON_SASS          ICON_STR("", "", ICON_EXT_CSS)
 #define ICON_SCRIPT        ICON_STR(MFIZZ_SCRIPT, "", "📜")
 #define ICON_SUBTITLE      ICON_STR(FA_COMMENTS_O, "󰅺", "💬")
 #define ICON_TEMPLATES     ICON_STR(FA_PAPERCLIP, "󰗇", "📎")
 #define ICON_TEX           ICON_STR(FILE_TEX, "󰙩", ICON_DOCUMENT)
-#define ICON_VIDEOFILE     ICON_STR(FA_FILE_MOVIE_O, "󰈫", ICON_VIDEOS)
-#define ICON_VIDEOS        ICON_STR(FA_FILM, "󰈰", "🎞 ")
+#define ICON_VIDEOFILE     ICON_STR(FA_FILE_MOVIE_O, "󰈫", "🎞 ")
+#define ICON_VIDEOS        ICON_STR(FA_FILM, "󰈰", "🎬")
 #define ICON_VIM           ICON_STR(DEV_VIM, "", "")
 #define ICON_WORDDOC       ICON_STR(FILE_WORD, "󰈬", "📘")
 
 #define ICON_EXT_ASM       ICON_STR(FILE_NASM, "", "")
 #define ICON_EXT_BIN       ICON_STR(OCT_FILE_BINARY, "", "📓")
-#define ICON_EXT_COFFEE    ICON_STR(MFIZZ_COFFEE_BEAN, "", "")
+#define ICON_EXT_COFFEE    ICON_STR(MFIZZ_COFFEE_BEAN, "", ICON_JAVASCRIPT)
 #define ICON_EXT_CSS       ICON_STR(MFIZZ_CSS3, "", "🦋")
-#define ICON_EXT_DEB       ICON_STR(MFIZZ_DEBIAN, "", ICON_LINUX)
+#define ICON_EXT_DEB       ICON_STR(MFIZZ_DEBIAN, "", "🍥")
 #define ICON_EXT_DIFF      ICON_STR(FILE_DIFF, "", "📋")
 #define ICON_EXT_GO        ICON_STR(MFIZZ_GO, "󰟓", "")
 #define ICON_EXT_JSON      ICON_STR(ICON_JAVASCRIPT, "", ICON_JAVASCRIPT)
 #define ICON_EXT_LUA       ICON_STR(FILE_LUA, "", "🌘")
 #define ICON_EXT_M         ICON_STR("", "󰠞", "📊")
-#define ICON_EXT_MAT       ICON_STR("", "", "")
+#define ICON_EXT_MAT       ICON_STR("", "", ICON_EXT_M)
 #define ICON_EXT_MD        ICON_STR(DEV_MARKDOWN, "", "📝")
 #define ICON_EXT_MSI       ICON_STR(FA_WINDOWS, "󰍲", "🪟")
-#define ICON_EXT_NIX       ICON_STR("", "", "")
+#define ICON_EXT_NIX       ICON_STR("", "", "❄️ ")
 #define ICON_EXT_PATCH     ICON_STR(FILE_PATCH, "", "🩹")
-#define ICON_EXT_PHP       ICON_STR(MFIZZ_PHP, "", "🌐")
-#define ICON_EXT_ROM       ICON_STR(FA_LOCK, "󰊖", "")
+#define ICON_EXT_PHP       ICON_STR(MFIZZ_PHP, "", ICON_HTML)
+#define ICON_EXT_ROM       ICON_STR(FA_LOCK, "󰊖", "🔒")
 #define ICON_EXT_RSS       ICON_STR(FA_RSS_SQUARE, "", "📡")
 #define ICON_EXT_RTF       ICON_STR(ICON_PDF, "󰈦", ICON_PDF)
 #define ICON_EXT_SCALA     ICON_STR(MFIZZ_SCALA, "", "")
 #define ICON_EXT_SLN       ICON_STR(DEV_VISUALSTUDIO, "", "")
-#define ICON_EXT_TS        ICON_STR(FILE_TS, "", "")
+#define ICON_EXT_TS        ICON_STR(FILE_TS, "", ICON_JAVASCRIPT)
 
 
 /*
@@ -321,6 +321,7 @@ static const struct icon_pair icons_ext[] = { /* All entries are case-insensitiv
 	{"lhs",        ICON_HASKELL,        COLOR_VIM},
 	{"log",        ICON_DOCUMENT,       0},
 	{"lua",        ICON_EXT_LUA,        COLOR_LUA},
+	{"lz",         ICON_ARCHIVE,        COLOR_ARCHIVE},
 	{"lzh",        ICON_ARCHIVE,        COLOR_ARCHIVE},
 	{"lzma",       ICON_ARCHIVE,        COLOR_ARCHIVE},
 
